==> qtjambi-xml-5.15.4-sources.jar: io/qt/xml/QXmlDeclHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report declaration content of XML data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html">QXmlDeclHandler</a></p>
 */
@Deprecated
public interface QXmlDeclHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlDeclHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlDeclHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlDeclHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean attributeDecl(java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value){
                return attributeDecl_native_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), eName, aName, type, valueDefault, value);
            }
            private native static boolean attributeDecl_native_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean externalEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId){
                return externalEntityDecl_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId);
            }
            private native static boolean externalEntityDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean internalEntityDecl(java.lang.String name, java.lang.String value){
                return internalEntityDecl_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, value);
            }
            private native static boolean internalEntityDecl_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String value);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlDeclHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#attributeDecl">QXmlDeclHandler::attributeDecl(QString,QString,QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean attributeDecl(java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
        
        private native static boolean attributeDecl_native_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#errorString">QXmlDeclHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#externalEntityDecl">QXmlDeclHandler::externalEntityDecl(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean externalEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        private native static boolean externalEntityDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#internalEntityDecl">QXmlDeclHandler::internalEntityDecl(QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean internalEntityDecl(java.lang.String name, java.lang.String value);
        
        private native static boolean internalEntityDecl_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String value);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#attributeDecl">QXmlDeclHandler::attributeDecl(QString,QString,QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean attributeDecl(java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#errorString">QXmlDeclHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#externalEntityDecl">QXmlDeclHandler::externalEntityDecl(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean externalEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#internalEntityDecl">QXmlDeclHandler::internalEntityDecl(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean internalEntityDecl(java.lang.String name, java.lang.String value);
    
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QXmlDeclHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report declaration content of XML data</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html">QXmlDeclHandler</a></p>
 */
@Deprecated
public interface QXmlDeclHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlDeclHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlDeclHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlDeclHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean attributeDecl(java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value){
                return attributeDecl_native_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), eName, aName, type, valueDefault, value);
            }
            private native static boolean attributeDecl_native_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean externalEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId){
                return externalEntityDecl_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, publicId, systemId);
            }
            private native static boolean externalEntityDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean internalEntityDecl(java.lang.String name, java.lang.String value){
                return internalEntityDecl_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name, value);
            }
            private native static boolean internalEntityDecl_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String value);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlDeclHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#attributeDecl">QXmlDeclHandler::attributeDecl(QString,QString,QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean attributeDecl(java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
        
        private native static boolean attributeDecl_native_cref_QString_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#errorString">QXmlDeclHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#externalEntityDecl">QXmlDeclHandler::externalEntityDecl(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean externalEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        private native static boolean externalEntityDecl_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String publicId, java.lang.String systemId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#internalEntityDecl">QXmlDeclHandler::internalEntityDecl(QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean internalEntityDecl(java.lang.String name, java.lang.String value);
        
        private native static boolean internalEntityDecl_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String name, java.lang.String value);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#attributeDecl">QXmlDeclHandler::attributeDecl(QString,QString,QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean attributeDecl(java.lang.String eName, java.lang.String aName, java.lang.String type, java.lang.String valueDefault, java.lang.String value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#errorString">QXmlDeclHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#externalEntityDecl">QXmlDeclHandler::externalEntityDecl(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean externalEntityDecl(java.lang.String name, java.lang.String publicId, java.lang.String systemId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmldeclhandler.html#internalEntityDecl">QXmlDeclHandler::internalEntityDecl(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean internalEntityDecl(java.lang.String name, java.lang.String value);
    
}
